### Hidden class
Dynamically generated classes provide efficiency and flexibility for low-latency applications.
Since Java 15, hidden classes have become a standard way to generate dynamic classes.
Hidden classes are classes that cannot be used directly by the bytecode or other classes.
Properties of these dynamically generated classes:
1. Non-discoverable – a hidden class is not discoverable by the JVM during bytecode linkage, 
nor by programs making explicit use of class loaders. 
The reflective methods Class::forName, ClassLoader::findLoadedClass, 
and Lookup::findClass will not find them.
2. We can't use the hidden class as a superclass, field type, return type, or parameter type.
3. Code in the hidden class can use it directly, without relying on the class object.
4. final fields declared in hidden classes are not modifiable regardless of their accessible flags.
5. It extends the access control nest with non-discoverable classes.
6. It may be unloaded even though its notional defining class loader is still reachable.
7. Stack traces don't show the methods or names of hidden classes by default, however, tweaking JVM options can show them.


Yoyr task is to implement: 
``` 
IHidden getHiddenOb(Class<?> clazz)
``` 
which return an instance of clazz
and verify some properties of hidden class by complete the method: 
```
String verifyProperties(MethodHandles.Lookup lookup, Class<?> clazz)
```
### Sample output:
```
HELLO
isHidden =true
getCanonicalName =null
getName =Hidden/0x0000000800c04800
Class.forName failed: Hidden/0x0000000800c04800
lookup.findClass failed: Hidden/0x0000000800c04800

```