import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

import java.lang.reflect.Method;
import java.util.ArrayList;
import java.util.List;

public class CopyrightPrinterTest {
    record Answer(String methodName, String copyrightInfo){
        @Override public String toString(){return "Method \"" + methodName()+"\" has annotation:" + copyrightInfo();}
    }

    @Test
    public void testPrintMethodCopyrightInfoNoAnnotatedMethods() {
        String[] actual = CopyrightPrinter.gettMethodCopyrightInfo(Object.class).stream().map(CopyrightPrinter.Answer::toString).toArray(String[]::new);
        String[] expected = gettMethodCopyrightInfo(Object.class).stream().map(Answer::toString).toArray(String[]::new);

        Assertions.assertArrayEquals(expected,actual, "No annotated methods, method shouldn't print anything");
    }

    @Test
    public void testPrintMethodCopyrightInfo() {
        String[] actual = CopyrightPrinter.gettMethodCopyrightInfo(CopyrightExample.class).stream().map(CopyrightPrinter.Answer::toString).toArray(String[]::new);
        String[] expected = gettMethodCopyrightInfo(CopyrightExample.class).stream().map(Answer::toString).toArray(String[]::new);

        Assertions.assertArrayEquals(expected,actual, "Annotated method name with its copyright info should be printed");
    }
    
    public static List<Answer> gettMethodCopyrightInfo(Class<?> c) {
        List<Answer> answers = new ArrayList<>();
        for (Method m : c.getDeclaredMethods()) {
            if(m.isAnnotationPresent(Copyright.class)){
                Copyright copyright = m.getAnnotation(Copyright.class);
                answers.add( new Answer(m.getName(),copyright.info()));
            }
        }
        return answers;
    }

}
