import java.util.HashMap;
import java.util.Map;

public class ShapeFactory {
    private final Map<ShapeType, Shape> shapes = new HashMap<>();
    private final Map<ShapeType, Map<String, Shape>> maps = new HashMap<>();

    // color -> instance

    public ShapeFactory() {
       maps.put(ShapeType.LINE, new HashMap<String, Shape>());
       maps.put(ShapeType.SQUARE, new HashMap<String, Shape>());
       maps.put(ShapeType.SQUARE_FILLED, new HashMap<String, Shape>());
    }
    //The method should behave as below but returns factory object if possible.
    //  public Shape getShape(ShapeType shapeType){
    //    return switch(shapeType){
    //        case LINE -> new Line();
    //        case SQUARE -> new Square(Square.Filled.NOT_FILLED);
    //        case SQUARE_FILLED -> new Square(Square.Filled.FILLED);
    //        default -> throw new IllegalArgumentException("Invalid shape type");
    //    };
    //}
    public Shape getShape(ShapeType shapeType) {
        return switch(shapeType){
            case LINE -> shapes.computeIfAbsent(shapeType,x->new Line());
            case SQUARE -> shapes.computeIfAbsent(shapeType,x-> new Square(Square.Filled.NOT_FILLED));
            case SQUARE_FILLED -> shapes.computeIfAbsent(shapeType,x-> new Square(Square.Filled.FILLED));
            default -> throw new IllegalArgumentException("Invalid shape type");
        };
    }
    //The method should behave as below but returns factory object if possible.
    // public Shape getShape(ShapeType shapeType, String color) {
    //   return switch(shapeType){
    //            case LINE -> new Line(color);
    //            case SQUARE -> new Square(Square.Filled.NOT_FILLED, color);
    //            case SQUARE_FILLED -> new Square(Square.Filled.FILLED, color);
    //            default -> throw new IllegalArgumentException("Invalid shape type");
    //   };
    public Shape getShape(ShapeType shapeType, String color) {
        return switch(shapeType){
            case LINE -> maps.get(ShapeType.LINE).computeIfAbsent(color,x->new Line(color));
            case SQUARE -> maps.get(ShapeType.SQUARE).computeIfAbsent(color,x-> new Square(Square.Filled.NOT_FILLED,color));
            case SQUARE_FILLED -> maps.get(ShapeType.SQUARE_FILLED).computeIfAbsent(color,x-> new Square(Square.Filled.FILLED,color));
            default -> throw new IllegalArgumentException("Invalid shape type");
        };
    }
}
