import org.junit.jupiter.api.BeforeAll;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.*;

public class ShapeFactoryTest {
    private static ShapeFactory factory;

    @BeforeAll
    public static void setUp() {
        factory = new ShapeFactory();
    }

    @Test
    public void testGetShape() {
        Shape line = factory.getShape(ShapeType.LINE);
        Shape square = factory.getShape(ShapeType.SQUARE);
        Shape filledSquare = factory.getShape(ShapeType.SQUARE_FILLED);

        assertTrue(line instanceof Line);
        assertTrue(square instanceof Square);
        assertTrue(filledSquare instanceof Square);

        assertEquals(Square.Filled.NOT_FILLED, ((Square) square).getFilled());
        assertEquals(Square.Filled.FILLED, ((Square) filledSquare).getFilled());
    }

    @Test
    public void testGetShapeTwiceReturnSameObject() {
        Shape line1 = factory.getShape(ShapeType.LINE);
        Shape line2 = factory.getShape(ShapeType.LINE);

        assertEquals(line1, line2, "Calling getShape() for LINE twice should return the same instance");
    }

    @Test
    public void testGetShapeColors() {
        Shape yellowLine1 = factory.getShape(ShapeType.LINE, "yellow");
        Shape yellowLine2 = factory.getShape(ShapeType.LINE, "yellow");
        Shape orangeLine = factory.getShape(ShapeType.LINE, "orange");
        Shape orangeSquare = factory.getShape(ShapeType.SQUARE, "orange");

        assertEquals(yellowLine1, yellowLine2, "Calling getShape() for LINE with the same color twice should return the same instance");
        assertNotEquals(yellowLine1, orangeLine, "Calling getShape() for LINE with the different color should return different instance");
        assertNotEquals(orangeLine, orangeSquare, "Calling getShape() for LINE and SQUARE with the same color should return different instances");
    }
}
