import java.io.InputStream;
import java.lang.invoke.MethodHandles;


public class HiddenDemo {
    //The hidden class isn't created by any class loader.
    // It has the same defining class loader, runtime package, and protection domain of the lookup class.


    public static void main(String[] args) throws ReflectiveOperationException {
        //First, let's create a Lookup object:
        MethodHandles.Lookup lookup = MethodHandles.lookup();

        IHidden hiddenOb;
        Class<?> hiddenClass = getHiddenClass(lookup,Hidden.class);

        hiddenOb =  getHiddenOb(hiddenClass);
        System.out.println(hiddenOb.convertToUpperCase("Hello"));


        System.out.println(verifyProperties(lookup, hiddenClass));
    }

        //Now we can obtain an instance
        public static IHidden getHiddenOb(Class<?> clazz) throws  ReflectiveOperationException{
            //create new instance of Hidden class:
            return (IHidden) clazz.getConstructor().newInstance();
        }

        //Now, we can verify a few properties of a hidden class by invoking some of its methods:
        public static String verifyProperties(MethodHandles.Lookup lookup, Class<?> clazz) {
            String answer = "isHidden =" + clazz.isHidden() +
                    "\ngetCanonicalName =" + clazz.getCanonicalName() +
                    "\ngetName =" + clazz.getName();
            try {
                Class<?> c = Class.forName(clazz.getName());
            } catch (Exception e) {
                answer = answer + "\nClass.forName failed: "+ e.getMessage();
            }
            try {
                Class<?> c = lookup.findClass(clazz.getName());
            } catch (Exception e) {
                answer = answer + "\nlookup.findClass failed: " + e.getMessage();
            }
            return answer;
        }

    public static Class<?> getHiddenClass(MethodHandles.Lookup lookup, Class<?> toHide) throws IllegalAccessException {
        byte[] bytes = null;

        //Let's get the path of the class and load it into the input stream.
        // After that, we'll convert this class into bytes using IOUtils.toByteArray():
        String className = toHide.getName();
        String classAsPath = className.replace('.', '/') + ".class";
        try(InputStream stream = toHide.getClassLoader().getResourceAsStream(classAsPath)){
            assert stream != null;
            bytes = stream.readAllBytes();
        }catch(Exception e){
            System.err.println(e.getMessage());
        }

        //Lastly, we pass these constructed bytes into Lookup::defineHiddenClass:
        assert bytes != null;
        return lookup.defineHiddenClass(bytes,
                true, MethodHandles.Lookup.ClassOption.NESTMATE).lookupClass();
    }
}
