import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.BeforeAll;
import org.junit.jupiter.api.Test;

import java.io.InputStream;
import java.lang.invoke.MethodHandles;

public class HiddenDemoTests {
  private static final MethodHandles.Lookup lookup = MethodHandles.lookup();
  private static Class<?> hiddenClass;

  @BeforeAll
  static void setUp() throws IllegalAccessException {
      hiddenClass =  getHiddenClass(lookup,Hidden.class);
  }

  @Test
  public void testgetHiddenOb() {
    Assertions.assertDoesNotThrow(
            ()->{ IHidden hidden;
              hidden =  getHiddenOb(hiddenClass);
              Assertions.assertEquals("HELLO",hidden.convertToUpperCase("Hello"));
            }
    );
  }

  @Test
  public void testverifyProperties() throws IllegalAccessException {
    String expected = verifyProperties(lookup,hiddenClass);
    String actual = HiddenDemo.verifyProperties(lookup,hiddenClass);
    Assertions.assertEquals(expected,actual);

  }

  public static IHidden getHiddenOb(Class<?> clazz) throws  ReflectiveOperationException{
    //create new instance of Hidden class:
    return (IHidden) clazz.getConstructor().newInstance();

  }
  public static String verifyProperties(MethodHandles.Lookup lookup, Class<?> clazz) {
    String answer = "isHidden =" + clazz.isHidden() +
            "\ngetCanonicalName =" + clazz.getCanonicalName() +
            "\ngetName =" + clazz.getName();
    try {
      Class<?> c = Class.forName(clazz.getName());
    } catch (Exception e) {
      answer = answer + "\nClass.forName failed: "+ e.getMessage();
    }
    try {
      Class<?> c = lookup.findClass(clazz.getName());
    } catch (Exception e) {
      answer = answer + "\nlookup.findClass failed: " + e.getMessage();
    }
    return answer;
  }
  public static Class<?> getHiddenClass(MethodHandles.Lookup lookup, Class<?> toHide) throws IllegalAccessException {
    byte[] bytes = null;

    //Let's get the path of the class and load it into the input stream.
    // After that, we'll convert this class into bytes using IOUtils.toByteArray():
    String className = toHide.getName();
    String classAsPath = className.replace('.', '/') + ".class";
    try(InputStream stream = toHide.getClassLoader().getResourceAsStream(classAsPath)){
      assert stream != null;
      bytes = stream.readAllBytes();
    }catch(Exception e){
      System.err.println(e.getMessage());
    }

    //Lastly, we pass these constructed bytes into Lookup::defineHiddenClass:
    assert bytes != null;
    return lookup.defineHiddenClass(bytes,
            true, MethodHandles.Lookup.ClassOption.NESTMATE).lookupClass();
  }
}