import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

class ClassWithPrivateConstructor {
    private ClassWithPrivateConstructor() {}
}

public class InstantiatorTest {
    private final Instantiator instantiator = new Instantiator();


    @Test
    public void createString() {
        Assertions.assertDoesNotThrow(()-> {
            Object object = instantiator.createInstance("java.lang.String");
            Assertions.assertTrue(object instanceof String, "String should be created");
        });
    }

    @Test
    public void createInvalid() {
        Assertions.assertThrows(ClassNotFoundException.class,()->instantiator.createInstance("java.lang.Nonexistent"));
    }



    @Test
    public void createWithPrivateConstructor() {
        Assertions.assertThrows(IllegalAccessException.class,()->instantiator.createInstance("A"));
    }
    @Test
    public void createWithNonExistingConstructor() {
        Assertions.assertThrows(NoSuchMethodException.class,()->instantiator.createInstance("B"));
    }
    @Test
    public void createWithNonDirectConstructor() {
        Assertions.assertDoesNotThrow(()->{
            Object object = instantiator.createInstance("C");
            Assertions.assertTrue(object instanceof C);
        });
    }
}

class A{
    private A(){}
}

class B{
    public B(int x){}
}

class C{}