package org.example;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Test;

import java.lang.reflect.Modifier;

public class AbstractionTests {
    @Test
    @DisplayName("Create Rectangle instance")
    public void testRectangleConstructor() {
        Assertions.assertDoesNotThrow(() -> new Rectangle(1.0, 2.0), "Exception thrown when constructor Rectangle(1.0, 2.0)");
    }

    @Test
    @DisplayName("Rectangle should extend Shape")
    public void testRectangleShape() {
        Assertions.assertTrue(Shape.class.isAssignableFrom(Rectangle.class), "Rectangle does not extend Shape");
    }

    @Test
    @DisplayName("Calculate Rectangle area")
    public void testRectangleArea() {
        var rectangle = Assertions.assertDoesNotThrow(() -> new Rectangle(3.0, 2.0), "Exception thrown when constructor Rectangle(1.0, 2.0)");
        Assertions.assertEquals(6.0, rectangle.area(), "Rectangle area calculated incorrectly");
    }

    @Test
    @DisplayName("Circle should be final")
    public void testCircleIsFinal() {
        Assertions.assertTrue(Modifier.isFinal(Circle.class.getModifiers()), "Circle class is not final");
    }

    @Test
    @DisplayName("Triangle should be a subclass of Shape class")
    public void testTriangleIsSubclassOfShape() {
        Assertions.assertTrue(Shape.class.isAssignableFrom(Triangle.class), "Triangle is not Shape subclass");
    }

    @Test
    @DisplayName("Shape should be abstract")
    public void testShapeIsAbstract() {
        Assertions.assertTrue(Modifier.isAbstract(Shape.class.getModifiers()), "Shape is not abstract");
    }

    @Test
    @DisplayName("Shape should have an abstract method area")
    public void testShapeHaveAbstractAreaMethod() {
        var method = Assertions.assertDoesNotThrow(() -> Shape.class.getMethod("area"), "Shape does not have method: area");
        Assertions.assertTrue(Modifier.isAbstract(method.getModifiers()), "Shape method: area is not final");
        Assertions.assertEquals(0, method.getParameterTypes().length, "Shape method: area is not parameterless");
    }
}