package org.example;

import org.example.renderable.Renderable;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.*;

class BoardTest {
    //
    // After initialization Game should contain specific number of players (parameter)
    // Initial position of player can be random
    // Player cannot be placed on rock
    // Two Players cannot occupy the same location
    //

    @Test
    @DisplayName("board has a frame")
    public void frameCheck() {
        final var board = new Board(10, 10);

        final var checker = new FrameChecker();
        board.render(checker);
        assertTrue(checker.valid);
    }

    @Test
    @DisplayName("board is not empty internally")
    public void internalCheck() {
        final var board = new Board(10, 10);

        final var checker = new InternalChecker();
        board.render(checker);
        assertTrue(checker.valid);
    }

}

class InternalChecker implements Renderable {
    boolean valid = false;

    @Override
    public void render(char[] tbl, int height, int width) {
        for (int j = 1; j < height; j++) {
            for (int i = 1; i < width - 1; i++) {
                if (tbl[j*width + i] == 'x') {
                    valid = true;
                    return;
                }
            }
        }
    }
}

class FrameChecker implements Renderable {
    boolean valid = true;

    @Override
    public void render(char[] tbl, int height, int width) {
        for (int j = 0; j < height; j++) {
            if (tbl[j * width + 0] != 'x') {
                valid = false;
                return;
            }
            if (tbl[j * width + width - 1] != 'x') {
                valid = false;
                return;
            }
        }

        for (int i = 0; i < width; i++) {
            if (tbl[i] != 'x') {
                valid = false;
                return;
            }
        }

        for (int i = 0; i < width; i++) {
            if (tbl[(height - 1) * width + i] != 'x') {
                valid = false;
                return;
            }
        }
    }
}
