import datetime
import os
import json
from openai import OpenAI, organization

# Configuration file containing the API key
CONFIG_FILE = 'config.json'

# Load API key from the configuration file
try:
    with open(CONFIG_FILE, 'r') as config:
        data = json.load(config)
except Exception as e:
    print(f"Error loading API key from {CONFIG_FILE}: {e}")
    exit(1)

# Set your OpenAI API key
api_key = data['api_key']
organization = data['organization']
project = data['project']
client = OpenAI(api_key=api_key, organization=organization, project=project)

# Directories for prompts and responses
PROMPTS_DIR = 'prompts'
current_date = datetime.datetime.now().strftime('%Y.%m.%d')
RESPONSES_DIR = os.path.join('responses', 'openai', current_date)

# Ensure the responses directory exists
os.makedirs(RESPONSES_DIR, exist_ok=True)

# Get list of prompt files with .md extension
prompt_files = [f for f in os.listdir(PROMPTS_DIR) if f.endswith('.md')]

for prompt_file in prompt_files:
    prompt_path = os.path.join(PROMPTS_DIR, prompt_file)
    response_path = os.path.join(RESPONSES_DIR, prompt_file)

    # Skip if response file already exists
    if os.path.exists(response_path):
        print(f"Response for '{prompt_file}' already exists. Skipping.")
        continue

    # Read the prompt content
    with open(prompt_path, 'r', encoding='utf-8') as file:
        prompt_content = file.read()

    # Call the OpenAI API to get the response
    try:
        response = client.chat.completions.create(
            model='gpt-4o',
            messages=[{'role': 'user', 'content': prompt_content}],
            temperature=1.0)
        assistant_reply = response.choices[0].message.content

        # Write the response to the responses folder
        with open(response_path, 'w', encoding='utf-8') as file:
            file.write(assistant_reply)

        print(f"Processed '{prompt_file}' successfully.")

    except Exception as e:
        print(f"Error processing '{prompt_file}': {e}")
