import datetime
import json
import google.generativeai as genai
import os

def main():
    # Configuration file containing the API key
    config_file = 'settings.json'

    # Load API key from the configuration file
    try:
        with open(config_file, 'r') as config:
            data = json.load(config)
    except Exception as e:
        print(f"Error loading API key from {config_file}: {e}")
        exit(1)

    # Set your OpenAI API key
    api_key = data['apiKey']

    genai.configure(api_key=api_key)
    model = genai.GenerativeModel('gemini-1.5-pro')

    prompts_folder = 'prompts'
    current_date = datetime.datetime.now().strftime('%Y.%m.%d')
    responses_folder = os.path.join('responses', 'gemini', current_date)

    # Ensure the responses folder exists
    os.makedirs(responses_folder, exist_ok=True)

    # List all prompt files ending with .md
    prompt_files = [f for f in os.listdir(prompts_folder) if f.endswith('.md')]

    for prompt_file in prompt_files:
        prompt_path = os.path.join(prompts_folder, prompt_file)
        response_path = os.path.join(responses_folder, prompt_file)

        # Check if the response file already exists
        if os.path.exists(response_path):
            print(f"Response for '{prompt_file}' already exists. Skipping.")
            continue

        # Read the prompt content
        with open(prompt_path, 'r', encoding='utf-8') as f:
            prompt_text = f.read()

        try:
            response = model.generate_content(prompt_text)

            # Write the response to the responses folder
            with open(response_path, 'w', encoding='utf-8') as f:
                f.write(response.text)

            print(f"Processed '{prompt_file}', response saved to '{response_path}'.")

        except Exception as e:
            print(f"Error processing '{prompt_file}': {e}")

if __name__ == '__main__':
    main()
