## Java Operators

Welcome to this lecture on Java Operators! Operators are special symbols that perform specific operations on operands (values) and return a result. They are fundamental to programming and allow us to manipulate data within our code.

This lecture will cover:

* Arithmetic Operators
* Relational Operators
* Logical Operators
* Assignment Operators

Let's dive in!

## Arithmetic Operators

Arithmetic operators are used to perform mathematical calculations on numerical data types.

| Operator | Description | Example | Output |
|---|---|---|---|
| `+` | Addition | `10 + 5` | `15` |
| `-` | Subtraction | `10 - 5` | `5` |
| `*` | Multiplication | `10 * 5` | `50` |
| `/` | Division | `10 / 5` | `2` |
| `%` | Modulo (Remainder) | `10 % 3` | `1` |

**Example:**

```java
int x = 10;
int y = 5;

int sum = x + y; // sum = 15
int difference = x - y; // difference = 5
int product = x * y; // product = 50
int quotient = x / y; // quotient = 2
int remainder = x % y; // remainder = 0
```

**Important Note:** When performing division with integer operands, the result will also be an integer. Any decimal part is truncated. 

**Resource:**

* [Java Arithmetic Operators - W3Schools](https://www.w3schools.com/java/java_operators.asp)

## Relational Operators

Relational operators are used to compare two operands and determine the relationship between them. They return a boolean value (`true` or `false`) based on the comparison.

| Operator | Description | Example | Output |
|---|---|---|---|
| `==` | Equal to | `10 == 10` | `true` |
| `!=` | Not equal to | `10 != 5` | `true` |
| `>` | Greater than | `10 > 5` | `true` |
| `<` | Less than | `5 < 10` | `true` |
| `>=` | Greater than or equal to | `10 >= 10` | `true` |
| `<=` | Less than or equal to | `5 <= 10` | `true` |

**Example:**

```java
int a = 5;
int b = 10;

boolean isEqual = a == b; // isEqual = false
boolean isGreater = a > b; // isGreater = false
boolean isLessOrEqual = a <= b; // isLessOrEqual = true
```

**Resource:**

* [Java Relational Operators - GeeksforGeeks](https://www.geeksforgeeks.org/relational-operators-in-java/)

## Logical Operators

Logical operators are used to combine multiple boolean expressions and evaluate the overall logic. 

| Operator | Description | Example | Output |
|---|---|---|---|
| `&&` | Logical AND | `true && true` | `true` (Both operands must be true) |
| `\|\|` | Logical OR | `true \|\| false` | `true` (At least one operand must be true) |
| `!` | Logical NOT | `!true` | `false` (Inverts the truth value) |

**Example:**

```java
int age = 25;
boolean hasLicense = true;

boolean canDrive = age >= 18 && hasLicense; // canDrive = true
boolean ineligible = age < 18 || !hasLicense; // ineligible = false
```

**Resource:**

* [Java Logical Operators - TutorialsPoint](https://www.tutorialspoint.com/java/java_logical_operators_examples.htm)

## Assignment Operators

Assignment operators assign a value to a variable. While `=` is the basic assignment operator, Java offers shorthand assignment operators for convenience.

| Operator | Description | Equivalent to | Example |
|---|---|---|---|
| `=` | Assignment |  | `x = 10;` |
| `+=` | Add and assign | `x = x + 5;` | `x += 5;` |
| `-=` | Subtract and assign | `x = x - 5;` | `x -= 5;` |
| `*=` | Multiply and assign | `x = x * 5;` | `x *= 5;` |
| `/=` | Divide and assign | `x = x / 5;` | `x /= 5;` |
| `%=` | Modulo and assign | `x = x % 5;` | `x %= 5;` |

**Example:**

```java
int num = 10;

num += 5; // num is now 15
num *= 2; // num is now 30
num /= 3; // num is now 10
```

**Resource:**

* [Java Assignment Operators - Programiz](https://www.programiz.com/java-programming/operators)

This concludes our lecture on Java operators. Understanding these operators is crucial for writing effective and efficient Java code. 
