# Java Course Material: Java Comments

## Overview
Comments are an essential part of any programming language, including Java. They provide helpful context or explanation to the code for anyone reading it, including your future self. Java supports three kinds of comments: single-line, multi-line, and Javadoc comments. Each has specific uses, and understanding their differences is vital for writing clear, maintainable code.

---

## 1. Single-Line Comments

### Description
Single-line comments start with two forward slashes (`//`). The compiler ignores everything from the `//` to the end of the line. Use them for brief explanations or notes about a particular line of code. 

### Syntax
```java
// This is a single-line comment
int number = 10; // Assign 10 to variable 'number'
```

### Example
Here's an example illustrating the use of single-line comments:

```java
public class Example {
    public static void main(String[] args) {
        // Print a welcome message to the console
        System.out.println("Welcome to Java Programming!");
        
        int sum = 5 + 3; // This adds 5 and 3
        System.out.println("Sum is: " + sum);
    }
}
```

### References
- [Java Tutorial: Java Comments](https://docs.oracle.com/javase/tutorial/java/nutsandbolts/comments.html)

---

## 2. Multi-Line Comments

### Description
Multi-line comments, also known as block comments, begin with `/*` and end with `*/`. Everything enclosed between these symbols is part of the comment. They are useful for comments that span multiple lines or to temporarily disable blocks of code during testing.

### Syntax
```java
/*
    This is a multi-line comment
    It can span several lines
*/
```

### Example
Multi-line comments can include detailed explanations, which can be useful during development or future code reviews:

```java
public class Calculation {
    public static void main(String[] args) {
        /*
            The following lines perform
            a simple subtraction operation
            and print the result.
        */
        int a = 10;
        int b = 5;
        int result = a - b;
        
        System.out.println("The result is: " + result);
    }
}
```

### References
- [Official Java Documentation on Multiline Comments](https://www.oracle.com/java/technologies/javase/codeconventions-comments.html)

---

## 3. Javadoc Comments

### Description
Javadoc comments are used to generate HTML documentation for Java code. They begin with `/**` and end with `*/`. They are usually placed before class, method, or field declarations and can include special tags like `@param`, `@return`, and `@throws` to provide structured information about the code.

### Syntax
```java
/**
 * Brief description about the method or class.
 * 
 * @param parameterName Description of the parameter.
 * @return Description of the return value.
 * @throws ExceptionType Description of the exception condition.
 */
```

### Example
Below is an example of how to use Javadoc comments in a Java program:

```java
/**
 * The Calculator class provides methods
 * to perform arithmetic operations.
 */
public class Calculator {

    /**
     * Adds two integers and returns the sum.
     *
     * @param a the first integer
     * @param b the second integer
     * @return the sum of a and b
     */
    public int add(int a, int b) {
        return a + b;
    }

    /**
     * Subtracts one integer from another and returns the result.
     *
     * @param a the integer to be subtracted from
     * @param b the integer to subtract
     * @return the result of subtracting b from a
     */
    public int subtract(int a, int b) {
        return a - b;
    }
}
```

### References
- [Javadoc Documentation Guide](https://www.oracle.com/technical-resources/articles/java/javadoc-tool.html)
- [How to Write Doc Comments for the Javadoc Tool](https://www.oracle.com/technetwork/java/javase/documentation/index-137868.html)

---
With a sound understanding of all three types of comments, you can write clearer, more understandable code. By commenting thoughtfully, you enhance the maintainability and readability of your programs, making it easier for others (and yourself) to understand the logic and functionality of your code.