# Java Programming Course

This course material is designed to provide an in-depth understanding of Java programming, focusing on program structure and naming conventions. The presentation is structured in Markdown format for easy readability and adaptability.

## Java Program Structure

A Java program is composed of classes and methods, and typically consists of the following components:

### Basic Structure

1. **Package Declaration:** The first line in the source file. It defines the namespace in which classes are stored.

    ```java
    package com.example.myproject;
    ```

2. **Import Statements:** These allow the use of classes from other packages without using their fully qualified names.

    ```java
    import java.util.List;
    ```

3. **Class Declaration:** Each Java program must have at least one class declaration.

    ```java
    public class MyClass {
        public static void main(String[] args) {
            System.out.println("Hello, World!");
        }
    }
    ```

4. **Methods:** Blocks of code that perform operations. The `main` method is the entry point of a Java program.

    ```java
    public void myMethod() {
        // method body
    }
    ```

### Example

```java
package com.example.demo;

import java.util.Scanner;

public class Example {
    public static void main(String[] args) {
        Scanner scanner = new Scanner(System.in);
        System.out.println("Enter your name: ");
        String name = scanner.nextLine();
        System.out.println("Hello, " + name + "!");
    }
}
```

### References

- [Java Documentation](https://docs.oracle.com/javase/tutorial/)
- "Effective Java" by Joshua Bloch

## Java Naming Conventions

Conventions facilitate readability and maintenance, helping teams collaborate more effectively.

### Class Naming Conventions

- Classes should be nouns, in mixed case with the first letter of each internal word capitalized.

    ```java
    public class EmployeeDetails {
        // class body
    }
    ```

#### References

- [Oracle Java Naming Conventions](https://www.oracle.com/java/technologies/javase/codeconventions-namingconventions.html)

### Package Naming Conventions

- Packages are named in all lower case to avoid conflicts with class names.
- Follow the hierarchical naming pattern, using reversed Internet domain names.

    ```java
    package com.example.project.module;
    ```

#### References

- [Java Package Naming Conventions](https://docs.oracle.com/javase/tutorial/java/package/namingpkgs.html)

### Variable Naming Conventions

- Variables should be in mixed case. Use meaningful and specific names.

    ```java
    int numberOfEmployees;
    ```

#### Example

```java
String firstName;
int maxSpeed;
```

#### References

- "Java: The Complete Reference" by Herbert Schildt

### Method Naming Conventions

- Methods should be verbs, in mixed case with the first letter lowercase, and with the first letter of each internal word capitalized.

    ```java
    public void calculateSalary() {
        // method body
    }
    ```

#### Example

```java
public int getValue() {
    return this.value;
}
```

#### References

- [Oracle Java Documentation](https://docs.oracle.com/javase/tutorial/java/nutsandbolts/)

By adhering to Java's structured framework and naming conventions, you can write clean, organized, and efficient code. This structured approach not only ensures developers' ease of understanding but also contributes significantly to the robustness and scalability of the codebase.