## Java Operators

Welcome to this lecture on Java Operators! Operators are special symbols that perform specific operations on one, two, or three operands (values) and then return a result. 

This presentation covers:

1. **Arithmetic Operators**
2. **Relational Operators**
3. **Logical Operators**
4. **Assignment Operators**

Let's dive into each type!

## 1. Arithmetic Operators

Arithmetic operators are used to perform mathematical operations on numerical data types.

| Operator | Description | Example |
|---|---|---|
| `+` | Addition | `5 + 2` results in `7` |
| `-` | Subtraction | `5 - 2` results in `3` |
| `*` | Multiplication | `5 * 2` results in `10` |
| `/` | Division | `5 / 2` results in `2` (integer division) |
| `%` | Modulus (remainder) | `5 % 2` results in `1` |
| `++` | Increment by 1 | `x++` is equivalent to `x = x + 1` |
| `--` | Decrement by 1 | `x--` is equivalent to `x = x - 1` |

**Example:**

```java
public class ArithmeticOperatorsExample {
    public static void main(String[] args) {
        int a = 10;
        int b = 3;

        System.out.println("a + b = " + (a + b)); // Output: 13
        System.out.println("a - b = " + (a - b)); // Output: 7
        System.out.println("a * b = " + (a * b)); // Output: 30
        System.out.println("a / b = " + (a / b)); // Output: 3 (integer division)
        System.out.println("a % b = " + (a % b)); // Output: 1

        a++; 
        System.out.println("a++ = " + a); // Output: 11

        b--;
        System.out.println("b-- = " + b); // Output: 2
    }
}
```

**References:**

* [Java Arithmetic Operators - W3Schools](https://www.w3schools.com/java/java_operators.asp)
* [Java Operators - Tutorialspoint](https://www.tutorialspoint.com/java/java_operators.htm)

## 2. Relational Operators

Relational operators are used to compare two values and return a boolean result (`true` or `false`).

| Operator | Description | Example |
|---|---|---|
| `==` | Equal to | `5 == 5` results in `true` |
| `!=` | Not equal to | `5 != 4` results in `true` |
| `>` | Greater than | `5 > 4` results in `true` |
| `<` | Less than | `4 < 5` results in `true` |
| `>=` | Greater than or equal to | `5 >= 5` results in `true` |
| `<=` | Less than or equal to | `4 <= 5` results in `true` |

**Example:**

```java
public class RelationalOperatorsExample {
    public static void main(String[] args) {
        int x = 10;
        int y = 5;

        System.out.println("x == y: " + (x == y)); // Output: false
        System.out.println("x != y: " + (x != y)); // Output: true
        System.out.println("x > y: " + (x > y)); // Output: true
        System.out.println("x < y: " + (x < y)); // Output: false
        System.out.println("x >= y: " + (x >= y)); // Output: true
        System.out.println("x <= y: " + (x <= y)); // Output: false
    }
}
```

**References:**

* [Java Relational Operators - W3Schools](https://www.w3schools.com/java/java_operators.asp)
* [Java Operators - Tutorialspoint](https://www.tutorialspoint.com/java/java_operators.htm)

## 3. Logical Operators

Logical operators are used to combine two or more boolean expressions and return a boolean result.

| Operator | Description | Example |
|---|---|---|
| `&&` | Logical AND | Returns `true` if both operands are `true` |
| `||` | Logical OR | Returns `true` if at least one operand is `true` |
| `!` | Logical NOT | Reverses the logical state of its operand |

**Example:**

```java
public class LogicalOperatorsExample {
    public static void main(String[] args) {
        boolean a = true;
        boolean b = false;

        System.out.println("a && b: " + (a && b)); // Output: false
        System.out.println("a || b: " + (a || b)); // Output: true
        System.out.println("!a: " + (!a)); // Output: false
        System.out.println("!b: " + (!b)); // Output: true
    }
}
```

**References:**

* [Java Logical Operators - W3Schools](https://www.w3schools.com/java/java_operators.asp)
* [Java Operators - Tutorialspoint](https://www.tutorialspoint.com/java/java_operators.htm)

## 4. Assignment Operators

Assignment operators are used to assign a value to a variable.

| Operator | Description | Example |
|---|---|---|
| `=` | Simple assignment | `x = 10` assigns 10 to variable x |
| `+=` | Add and assign | `x += 5` is equivalent to `x = x + 5` |
| `-=` | Subtract and assign | `x -= 5` is equivalent to `x = x - 5` |
| `*=` | Multiply and assign | `x *= 5` is equivalent to `x = x * 5` |
| `/=` | Divide and assign | `x /= 5` is equivalent to `x = x / 5` |
| `%=` | Modulus and assign | `x %= 5` is equivalent to `x = x % 5` |

**Example:**

```java
public class AssignmentOperatorsExample {
    public static void main(String[] args) {
        int x = 10;

        x += 5;
        System.out.println("x += 5: " + x); // Output: 15

        x -= 3;
        System.out.println("x -= 3: " + x); // Output: 12

        x *= 2;
        System.out.println("x *= 2: " + x); // Output: 24

        x /= 4;
        System.out.println("x /= 4: " + x); // Output: 6

        x %= 5;
        System.out.println("x %= 5: " + x); // Output: 1
    }
}
```

**References:**

* [Java Assignment Operators - W3Schools](https://www.w3schools.com/java/java_operators.asp)
* [Java Operators - Tutorialspoint](https://www.tutorialspoint.com/java/java_operators.htm)

This concludes our lecture on Java Operators. Understanding and mastering these operators is crucial for writing efficient and effective Java code. Remember to practice using these operators in your own programs to solidify your understanding. 
