# Java Inheritance Presentation

## Slide 1: Introduction to Inheritance in Java
- **Title:** Introduction to Inheritance
- **Content:**
  - Inheritance is a fundamental concept in Object-Oriented Programming (OOP) that allows a new class to inherit properties and behaviors from an existing class.
  - Primary mechanism for code reuse and establishing a subtype from an existing class.
  - Promotes hierarchical class structures.

## Slide 2: Key Terminologies
- **Title:** Key Terminologies
- **Content:**
  - **Superclass (Parent Class):** The class whose properties are inherited.
  - **Subclass (Child Class):** The class that inherits from the superclass.
  - **`extends`:** Keyword used in Java to indicate that a class is inheriting from another class.

## Slide 3: Benefits of Inheritance
- **Title:** Benefits of Inheritance
- **Content:**
  - Encourages code reuse, reducing redundancy.
  - Enhances code maintainability.
  - Supports polymorphism, allowing objects to be treated as instances of their parent class.

## Slide 4: Syntax of Inheritance
- **Title:** Syntax of Inheritance
- **Content:**
  ```java
  class Superclass {
      // Superclass members (fields and methods)
  }

  class Subclass extends Superclass {
      // Additional fields and methods
  }
  ```

## Slide 5: Example of Inheritance
- **Title:** Example of Inheritance
- **Content:**
  ```java
  class Animal {
      void eat() {
          System.out.println("This animal eats food.");
      }
  }

  class Dog extends Animal {
      void bark() {
          System.out.println("The dog barks.");
      }
  }

  public class Main {
      public static void main(String[] args) {
          Dog myDog = new Dog();
          myDog.eat();  // Inherited method
          myDog.bark(); // Own method
      }
  }
  ```
  - **Explanation:**
    - `Dog` inherits `eat()` method from `Animal`.
    - `Dog` introduces an additional method `bark()`.

## Slide 6: Overriding Methods
- **Title:** Overriding Methods
- **Content:**
  - Subclasses can provide specific implementations for methods that are declared in a superclass.
  - Enables polymorphic behavior.
  - Use the `@Override` annotation as a best practice.

## Slide 7: Method Overriding Example
- **Title:** Method Overriding Example
- **Content:**
  ```java
  class Animal {
      void sound() {
          System.out.println("Animal makes a sound");
      }
  }

  class Cat extends Animal {
      @Override
      void sound() {
          System.out.println("Cat meows");
      }
  }

  public class Main {
      public static void main(String[] args) {
          Animal myCat = new Cat();
          myCat.sound(); // Outputs: Cat meows
      }
  }
  ```
  - **Explanation:**
    - `Cat` overrides `sound()` method of `Animal`.

## Slide 8: Inheritance and Constructors
- **Title:** Inheritance and Constructors
- **Content:**
  - Constructors are not inherited, but subclass constructors can invoke superclass constructors via `super()`.
  - `super()` must be the first statement in the subclass constructor.

## Slide 9: Example - Using super()
- **Title:** Example - Using super()
- **Content:**
  ```java
  class Animal {
      Animal() {
          System.out.println("Animal constructor");
      }
  }

  class Bird extends Animal {
      Bird() {
          super(); // Calls the superclass constructor
          System.out.println("Bird constructor");
      }
  }

  public class Main {
      public static void main(String[] args) {
          Bird myBird = new Bird();
          // Output: Animal constructor
          //         Bird constructor
      }
  }
  ```

## Slide 10: Inheritance and Access Modifiers
- **Title:** Inheritance and Access Modifiers
- **Content:**
  - `public`: Members are accessible everywhere.
  - `protected`: Members are accessible in subclasses and package.
  - `private`: Members are not accessible in subclasses.

## Slide 11: Final Keyword
- **Title:** The `final` Keyword
- **Content:**
  - Declaring a class as `final` prevents it from being subclassed.
  - Declaring a method as `final` prevents it from being overridden.

## Slide 12: Abstract Classes and Inheritance
- **Title:** Abstract Classes
- **Content:**
  - Abstract classes can have abstract methods (without implementation) that must be implemented by the subclasses.
  - They cannot be instantiated.

## Slide 13: References and Further Reading
- **Title:** References and Further Reading
- **Content:**
  - The Java™ Tutorials: [Inheritance](https://docs.oracle.com/javase/tutorial/java/IandI/subclasses.html)
  - Book: "Effective Java" by Joshua Bloch
  - Book: "Java: The Complete Reference" by Herbert Schildt
