---

# Polymorphism in Java

## Introduction to Polymorphism
- **Definition**: Polymorphism in object-oriented programming is the ability of a programming language to present the same interface for different data types. In Java, it allows one interface to be used for a general class of actions.

- **Types of Polymorphism**:
  1. **Compile-time Polymorphism** (Method Overloading)
  2. **Runtime Polymorphism** (Method Overriding)

- **Benefits**:
  - Code reusability
  - Flexibility
  - Simplifies code maintenance

## Compile-time Polymorphism (Method Overloading)

- **Method Overloading** allows multiple methods with the same name to exist in a class, differentiated by their parameter lists.

- **Example**: 
  ```java
  class Display {
      void show(int a) {
          System.out.println("Integer: " + a);
      }
      void show(String a) {
          System.out.println("String: " + a);
      }
  }

  public class TestOverloading {
      public static void main(String[] args) {
          Display obj = new Display();
          obj.show(100);
          obj.show("Hello");
      }
  }
  ```

- **Key Points**: 
  - Method name should be the same.
  - The parameter list must differ in type or number.
  - The return type can be different, but that alone doesn’t constitute overloading.

## Runtime Polymorphism (Method Overriding)

- **Method Overriding** occurs when a subclass provides a specific implementation of a method that is already defined in its superclass.

- **Example**:
  ```java
  class Vehicle {
      void run() {
          System.out.println("Vehicle is running");
      }
  }

  class Bike extends Vehicle {
      void run() {
          System.out.println("Bike is running safely");
      }
  }

  public class TestOverriding {
      public static void main(String[] args) {
          Vehicle obj = new Bike(); // Upcasting
          obj.run();
      }
  }
  ```

- **Key Points**:
  - The method in the child class must have the same name and parameters.
  - The return type must be compatible with the parent class version.
  - It is associated with the concept of Dynamic Method Dispatch.

## Polymorphism and Interfaces

- **Using Interfaces**: Polymorphism can also be achieved through interfaces.

- **Example**:
  ```java
  interface Animal {
      void makeSound();
  }

  class Dog implements Animal {
      public void makeSound() {
          System.out.println("Woof");
      }
  }

  class Cat implements Animal {
      public void makeSound() {
          System.out.println("Meow");
      }
  }

  public class TestInterfacePolymorphism {
      public static void main(String[] args) {
          Animal a;
          a = new Dog();
          a.makeSound();
          a = new Cat();
          a.makeSound();
      }
  }
  ```

## Conclusion
- Polymorphism is a core concept of object-oriented programming that helps in designing flexible and scalable systems. 
- Fundamental to achieving software extensibility and maintainability.

## References
- **Books**:
  - "Effective Java" by Joshua Bloch
  - "Java: The Complete Reference" by Herbert Schildt

- **Articles & Documentation**:
  - [Oracle Java Documentation - Interfaces](https://docs.oracle.com/javase/tutorial/java/IandI/interfaceAsType.html)
  - [GeeksforGeeks - Polymorphism](https://www.geeksforgeeks.org/polymorphism-in-java/)

- **Tutorials**:
  - [Java Polymorphism Tutorial - W3Schools](https://www.w3schools.com/java/java_polymorphism.asp)
