## Java Operators

Welcome to this lecture on Java Operators. Operators are special symbols that perform specific operations on one, two, or three operands (values) and then return a result. 

## Arithmetic Operators

Arithmetic operators are used to perform common mathematical operations on numerical data types.

| Operator | Description | Example |
|---|---|---|
| + | Addition | `int sum = 5 + 3; // sum will be 8` |
| - | Subtraction | `int difference = 10 - 4; // difference will be 6` |
| * | Multiplication | `int product = 7 * 2; // product will be 14` |
| / | Division | `int quotient = 15 / 3; // quotient will be 5` |
| % | Modulus (returns the remainder of a division) | `int remainder = 10 % 3; // remainder will be 1` |

**Example Code:**
```java
public class ArithmeticOperators {
    public static void main(String[] args) {
        int a = 10;
        int b = 3;

        System.out.println("a + b = " + (a + b));
        System.out.println("a - b = " + (a - b));
        System.out.println("a * b = " + (a * b));
        System.out.println("a / b = " + (a / b));
        System.out.println("a % b = " + (a % b));
    }
}
```

**Important Note:**  
* Division between integers results in an integer quotient, truncating any decimal portion. For a floating-point result, at least one operand must be a floating-point type (e.g., `10.0 / 3`). 

**Reference:**
* [Java Arithmetic Operators - W3Schools](https://www.w3schools.com/java/java_operators.asp)

## Relational Operators

Relational operators compare two operands and return a boolean value (`true` or `false`) based on the comparison. 

| Operator | Description | Example |
|---|---|---|
| == | Equal to | `int x = 5; boolean isEqual = (x == 5); // isEqual will be true` |
| != | Not equal to | `int y = 10; boolean isNotEqual = (y != 5); // isNotEqual will be true` |
| > | Greater than | `int a = 7; boolean isGreater = (a > 3); // isGreater will be true` |
| < | Less than | `int b = 2; boolean isLess = (b < 8); // isLess will be true` |
| >= | Greater than or equal to | `int c = 15; boolean isGreaterOrEqual = (c >= 15); // isGreaterOrEqual will be true` |
| <= | Less than or equal to | `int d = 9; boolean isLessOrEqual = (d <= 12); // isLessOrEqual will be true` |

**Example Code:**
```java
public class RelationalOperators {
    public static void main(String[] args) {
        int num1 = 10;
        int num2 = 5;

        System.out.println("num1 == num2: " + (num1 == num2));
        System.out.println("num1 != num2: " + (num1 != num2));
        System.out.println("num1 > num2: " + (num1 > num2));
        System.out.println("num1 < num2: " + (num1 < num2));
        System.out.println("num1 >= num2: " + (num1 >= num2));
        System.out.println("num1 <= num2: " + (num1 <= num2));
    }
}
```

**Reference:**
* [Java Relational Operators - TutorialsPoint](https://www.tutorialspoint.com/java/java_relational_operators_examples.htm)

## Logical Operators

Logical operators combine or modify boolean expressions. 

| Operator | Description | Example |
|---|---|---|
| && | Logical AND (returns `true` if both operands are `true`) | `boolean isTrue = (5 > 2) && (10 < 20); // isTrue will be true` |
| \|\| | Logical OR (returns `true` if at least one operand is `true`) | `boolean isAlsoTrue = (8 < 5) || (3 > 1); // isAlsoTrue will be true` |
| ! | Logical NOT (inverts the truth value of the operand) | `boolean isFalse = !(10 > 5); // isFalse will be false` |

**Example Code:**
```java
public class LogicalOperators {
    public static void main(String[] args) {
        int age = 25;
        boolean isStudent = false;

        boolean canVote = age >= 18;
        boolean canGetDiscount = isStudent && (age <= 30);

        System.out.println("Can Vote: " + canVote);
        System.out.println("Can Get Discount: " + canGetDiscount);
    }
}
```

**Reference:**
* [Java Logical Operators - GeeksforGeeks](https://www.geeksforgeeks.org/logical-operators-in-java/) 


## Assignment Operators

Assignment operators assign values to variables. They combine assignment with another operation (like arithmetic) for conciseness.

| Operator | Description | Example | Equivalent To |
|---|---|---|---|
| = | Simple assignment | `int x = 5;` |  |
| += | Add and assign | `x += 3;` | `x = x + 3;` |
| -= | Subtract and assign | `x -= 2;` | `x = x - 2;` |
| *= | Multiply and assign | `x *= 4;` | `x = x * 4;` |
| /= | Divide and assign | `x /= 2;` | `x = x / 2;` |
| %= | Modulus and assign | `x %= 3;` | `x = x % 3;` |

**Example Code:**
```java
public class AssignmentOperators {
    public static void main(String[] args) {
        int a = 10;

        a += 5; // a is now 15
        a -= 3; // a is now 12
        a *= 2; // a is now 24
        a /= 4; // a is now 6

        System.out.println("a = " + a);
    }
}
```

**Reference:**
* [Java Assignment Operators - Programiz](https://www.programiz.com/java-programming/operators) 
