package org.example;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

import java.lang.reflect.InvocationHandler;
import java.lang.reflect.Method;
import java.lang.reflect.Proxy;

import static org.junit.jupiter.api.Assertions.*;

class CalculatorTest {
    class MockCalculator implements InvocationHandler {

        @Override
        public Object invoke(Object proxy, Method method, Object[] args) throws Throwable {
            if (method.getName().equals("hex")) {
                final var value = (Integer)args[0];
                return String.format("%X", value);
            }

            if (method.getName().equals("add")) {
                final var a = (Integer)args[0];
                final var b = (Integer)args[1];
                return a + b;
            }
            return null;
        }
    }


    @Test
    void test1() {
        final var handler = new MockCalculator();

        Calculator proxy = (Calculator) Proxy.newProxyInstance(
                CalculatorTest.class.getClassLoader(),
                new Class[]{Calculator.class},
                handler);

        String hexString = proxy.hex(0xABCD);
        Assertions.assertEquals("ABCD", hexString);
    }

    @Test
    void test2() {
        final var handler = new MockCalculator();

        Calculator proxy = (Calculator) Proxy.newProxyInstance(
                CalculatorTest.class.getClassLoader(),
                new Class[]{Calculator.class},
                handler);

        final var result = proxy.add(2, 3);
        Assertions.assertEquals(5, result);
    }

}

interface Calculator {
    Integer add(Integer a, Integer b);
    Integer mul(Integer a, Integer b);

    void clear();
    Integer accumulate(Integer value);
}
